==> crosspki-0.0.1.tar.gz: android/src/main/java/com/lacunasoftware/flutter/crosspki/DroidCertificateStore.java <==
package com.lacunasoftware.flutter.crosspki;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.security.Key;
import java.security.KeyStore;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.cert.Certificate;
import java.security.cert.CertificateException;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Enumeration;

public class DroidCertificateStore {

	public static ArrayList<X509Certificate> listCertificatesWithKey() throws Exception {
		ArrayList<X509Certificate> certificates = new ArrayList<>();
		KeyStore ks = DroidKeyStore.getLoadedAndroidKeyStore();
		Enumeration<String> aliases = ks.aliases();

		while (aliases.hasMoreElements()) {
			String alias = aliases.nextElement();
			Certificate cert = ks.getCertificate(alias);
			if (cert instanceof X509Certificate
				&& DroidKeyStore.hasPrivateKey(ks, alias)
				&& !((X509Certificate)cert).getSubjectX500Principal().getName().startsWith(DroidKeyStore.pendingCertificateCN)) {

				certificates.add((X509Certificate)cert);
			}
		}

		return certificates;
	}

	public static void removeCertificate(byte[] certificateThumbprint) throws CertificateException, NoSuchAlgorithmException, KeyStoreException, IOException {
		try {
			KeyStore ks = DroidKeyStore.getLoadedAndroidKeyStore();
			String alias = findCertificate(certificateThumbprint, ks);
			ks.deleteEntry(alias);
		}catch (Exception e) {}
	}

	public static void importCertificate(byte[] certificateContent, String keyId) throws Exception {
		X509Certificate certificate = PkiUtil.decodeCertificate(certificateContent);
		KeyStore ks = DroidKeyStore.getLoadedAndroidKeyStore();
		if (!DroidKeyStore.hasPrivateKey(ks, keyId)) {
			throw new CrossPkiException(ErrorCodes.KEY_NOT_FOUND, String.format("Private key (%s) not found for certificate: %s", keyId, certificate.getSubjectX500Principal().getName()));
		}
		ks.setKeyEntry(keyId, ks.getKey(keyId, null), "".toCharArray(), new Certificate[] { certificate });
	}

	public static ArrayList<X509Certificate> importPkcs12(byte[] pkcs12Content, String password) throws Exception {
		ArrayList<X509Certificate> importedCertificates = new ArrayList<>();
		KeyStore p12 = KeyStore.getInstance("pkcs12");
		try (ByteArrayInputStream inputStream = new ByteArrayInputStream(pkcs12Content)) {
			p12.load(inputStream, password.toCharArray());
			Enumeration<String> aliases = p12.aliases();

			while (aliases.hasMoreElements()) {
				String alias = aliases.nextElement();
				if (!p12.isKeyEntry(alias)) {
					continue;
				}

				Key key = p12.getKey(alias, password.toCharArray());
				Certificate cert = p12.getCertificate(alias);
				if (key == null || cert == null) {
					continue;
				}

				if (cert instanceof X509Certificate) {
					X509Certificate x509Cert = (X509Certificate) cert;
					importedCertificates.add(x509Cert);
					KeyStore ks = DroidKeyStore.getLoadedAndroidKeyStore();
					ks.setKeyEntry(Util.createUniqueId(), key, "".toCharArray(), new Certificate[]{ cert });
				}
			}
		} catch (Exception e) {
			if (e.getMessage().toLowerCase().contains("wrong password") || e.getMessage().toLowerCase().contains("keystore password was incorrect")) {
				throw new CrossPkiException(ErrorCodes.WRONG_PASSWORD, e.getMessage(), e);
			}
			throw e;
		}
		return importedCertificates;
	}

	public static String findCertificate(byte[] certificateThumbprint) throws Exception {
		KeyStore ks = DroidKeyStore.getLoadedAndroidKeyStore();
		return findCertificate(certificateThumbprint, ks);
	}

	public static String findCertificate(byte[] certificateThumbprint, KeyStore ks) throws Exception {
		Enumeration<String> aliases = ks.aliases();

		while (aliases.hasMoreElements()) {
			String alias = aliases.nextElement();
			Certificate cert = ks.getCertificate(alias);
			try {
				byte[] thumbprint = PkiUtil.computeDigest(DigestAlgorithm.SHA256, cert.getEncoded());
				if (Arrays.equals(certificateThumbprint, thumbprint)) {
					return alias;
				}
			} catch (Exception e) {}
		}

		throw new CrossPkiException(ErrorCodes.CERTIFICATE_NOT_FOUND, "Certificate not found: " + Util.base64Encode(certificateThumbprint));
	}
}

==> crosspki-0.0.2.tar.gz: android/src/main/java/com/lacunasoftware/flutter/crosspki/DroidCertificateStore.java <==
package com.lacunasoftware.flutter.crosspki;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.security.Key;
import java.security.KeyStore;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;
import java.security.cert.Certificate;
import java.security.cert.CertificateException;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Enumeration;

public class DroidCertificateStore {

	public static ArrayList<X509Certificate> listCertificatesWithKey() throws Exception {
		ArrayList<X509Certificate> certificates = new ArrayList<>();
		KeyStore ks = DroidKeyStore.getLoadedAndroidKeyStore();
		Enumeration<String> aliases = ks.aliases();

		while (aliases.hasMoreElements()) {
			String alias = aliases.nextElement();
			Certificate cert = ks.getCertificate(alias);
			if (cert instanceof X509Certificate
				&& DroidKeyStore.hasPrivateKey(ks, alias)
				&& !((X509Certificate)cert).getSubjectX500Principal().getName().startsWith(DroidKeyStore.pendingCertificateCN)) {

				certificates.add((X509Certificate)cert);
			}
		}

		return certificates;
	}

	public static void removeCertificate(byte[] certificateThumbprint) {
		try {
			KeyStore ks = DroidKeyStore.getLoadedAndroidKeyStore();
			String alias = findCertificate(certificateThumbprint, ks);
			ks.deleteEntry(alias);
		}catch (Exception e) {}
	}

	public static void importCertificate(byte[] certificateContent, String keyId) throws Exception {
		X509Certificate certificate = PkiUtil.decodeCertificate(certificateContent);
		KeyStore ks = DroidKeyStore.getLoadedAndroidKeyStore();
		if (!DroidKeyStore.hasPrivateKey(ks, keyId)) {
			throw new CrossPkiException(ErrorCodes.KEY_NOT_FOUND, String.format("Private key (%s) not found for certificate: %s", keyId, certificate.getSubjectX500Principal().getName()));
		}
		ks.setKeyEntry(keyId, ks.getKey(keyId, null), "".toCharArray(), new Certificate[] { certificate });
	}

	public static ArrayList<X509Certificate> importPkcs12(byte[] pkcs12Content, String password) throws Exception {
		ArrayList<X509Certificate> importedCertificates = new ArrayList<>();
		KeyStore p12 = KeyStore.getInstance("pkcs12");
		try (ByteArrayInputStream inputStream = new ByteArrayInputStream(pkcs12Content)) {
			p12.load(inputStream, password.toCharArray());
			Enumeration<String> aliases = p12.aliases();

			while (aliases.hasMoreElements()) {
				String alias = aliases.nextElement();
				if (!p12.isKeyEntry(alias)) {
					continue;
				}

				Key key = p12.getKey(alias, password.toCharArray());
				Certificate cert = p12.getCertificate(alias);
				if (key == null || cert == null) {
					continue;
				}

				if (cert instanceof X509Certificate) {
					X509Certificate x509Cert = (X509Certificate) cert;
					importedCertificates.add(x509Cert);
					KeyStore ks = DroidKeyStore.getLoadedAndroidKeyStore();
					ks.setKeyEntry(Util.createUniqueId(), key, "".toCharArray(), new Certificate[]{ cert });
				}
			}
		} catch (Exception e) {
			if (e.getMessage().toLowerCase().contains("wrong password") || e.getMessage().toLowerCase().contains("keystore password was incorrect")) {
				throw new CrossPkiException(ErrorCodes.WRONG_PASSWORD, e.getMessage(), e);
			}
			throw e;
		}
		return importedCertificates;
	}

	public static String findCertificate(byte[] certificateThumbprint) throws Exception {
		KeyStore ks = DroidKeyStore.getLoadedAndroidKeyStore();
		return findCertificate(certificateThumbprint, ks);
	}

	public static String findCertificate(byte[] certificateThumbprint, KeyStore ks) throws Exception {
		Enumeration<String> aliases = ks.aliases();

		while (aliases.hasMoreElements()) {
			String alias = aliases.nextElement();
			Certificate cert = ks.getCertificate(alias);
			try {
				byte[] thumbprint = PkiUtil.computeDigest(DigestAlgorithm.SHA256, cert.getEncoded());
				if (Arrays.equals(certificateThumbprint, thumbprint)) {
					return alias;
				}
			} catch (Exception e) {}
		}

		throw new CrossPkiException(ErrorCodes.CERTIFICATE_NOT_FOUND, "Certificate not found: " + Util.base64Encode(certificateThumbprint));
	}
}
